import type { WriterOpts } from './write'
import { createWriter } from './write'

const writerClass = 'strichfolge-animation'

/// Initializes all hanzi writers in the current document
export async function init (): Promise<void> {
  const writerContainers = document.getElementsByClassName(writerClass)
  for (let i = 0; i < writerContainers.length; ++i) {
    const writerContainer = writerContainers[i]
    if (!writerContainer.classList.contains('is-initialized')) {
      const noAnimate = writerContainer.getAttribute('no-animate') !== null
      const strokeNums = writerContainer.getAttribute('animate-stroke')
      const highlightRadical = writerContainer
        .getAttribute('highlight-radical') !== null
      const text = (writerContainer.textContent ?? '').trim()
      const opts: WriterOpts = {
        addTo: writerContainer,
        text
      }
      if (strokeNums !== null) {
        const animateStrokeIndexes = strokeNums.split(/\s+/)
          // count from 0 in attribute
          .map(n => Number.parseInt(n) - 1)
        if (typeof opts.animate === 'undefined') {
          opts.animate = {}
        }
        opts.animate.strokes = animateStrokeIndexes
      }
      if (noAnimate) {
        if (typeof opts.animate === 'undefined') {
          opts.animate = {}
        }
        opts.animate.no = true
      }
      if (highlightRadical) {
        opts.highlightRadical = true
      }
      writerContainer.replaceChildren() // clear the text we just retrieved
      if (text.length > 0) {
        await createWriter(opts)
      }
      writerContainer.classList.add('is-initialized')
    }
  }
}
